@@ -1,27 +1,29 @@
+## File Name: lpcm_data_prep.R
+## File Version: 0.18
 
 ###################################################
 # data preparation function
 # linear logistic partial credit model
-lpcm_data_prep <- function( dat , weights , a ){
-    used_persons <- as.vector( which( rowSums( 1 - is.na(dat) ) > 1 ))
+lpcm_data_prep <- function( dat , weights , a )
+{
+	used_persons <- as.vector( which( rowSums( 1 - is.na(dat) ) > 1 ))
 	dat <- dat[ used_persons , ]
 	if ( ! is.null(weights) ){
 		weights <- weights[ used_persons ]
 	}
 	N <- nrow(dat)
 	I <- ncol(dat)
-	if ( is.null(a) ){
+	if( is.null(a) ){
 		a <- rep(1,I)
 	}
 	aM <- matrix( a , nrow=N , ncol=I , byrow=TRUE )
 	dat <- dat * aM
-	
+
 	dat_ind <- 1 * is.na(dat)
 	res <- sirt::md.pattern.sirt(dat_ind)
 	resp_patt <- res$resp_patt
-	
-	
-    if ( is.null(weights) ){
+
+	if ( is.null(weights) ){
 		weights <- rep(1 , N )
 							}
 	patt_unique <- unique( resp_patt )
@@ -48,15 +50,14 @@ lpcm_data_prep <- function( dat , weights , a ){
 	
 	K <- max( maxK )
 	for (kk in 1:K){
-    	f1 <- colSums( ( dat == kk ) * weights , na.rm=TRUE)
+		f1 <- colSums( ( dat == kk ) * weights , na.rm=TRUE)
 		ind <- pars_info[ pars_info$cat == kk , "itemid" ]
 		pars_info[ pars_info$cat == kk , "Freq" ] <- f1[ind]
-					}
+	}
 	parm_index <- sapply( 1:NP , FUN = function(pp){
-		 which( pars_info$itemid %in% item_index[[pp]] ) 
+			which( pars_info$itemid %in% item_index[[pp]] ) 
 			} , simplify=FALSE )
-			
-			
+
 	# calculate raw score
 	rs <- rowSums( dat , na.rm=TRUE)
 	score_freq <- sapply( 1:NP , FUN = function( pp ){
@@ -82,15 +83,15 @@ lpcm_data_prep <- function( dat , weights , a ){
 
 	# generate pararameter names
 	parnames <- paste0( pars_info$item , "_Cat" , pars_info$cat )	
-	rownames(pars_info) <- parnames					
+	rownames(pars_info) <- parnames	
 						
 	res <- list( N=N , I=I , NP=NP , dat=dat , 
-			      patt=patt , weights=weights ,
-				  suffstat=suffstat, splitvec=splitvec,
-				  item_index = item_index , parm_index=parm_index ,
-				  pars_info=pars_info , maxscore=maxscore ,
-				  maxK=maxK , score=rs , used_persons = used_persons ,
-				  score_freq = score_freq , a = a , parnames = parnames )	
-	return(res)	    
+					patt=patt , weights=weights ,
+					suffstat=suffstat, splitvec=splitvec,
+					item_index = item_index , parm_index=parm_index ,
+					pars_info=pars_info , maxscore=maxscore ,
+					maxK=maxK , score=rs , used_persons = used_persons ,
+					score_freq = score_freq , a = a , parnames = parnames )	
+	return(res)
 }
 ###################################################
